import React, { useState, useRef } from 'react';
import { Box, Typography, makeStyles, LinearProgress, Tooltip, Snackbar, Grid, Button } from '@material-ui/core';
import { stringifyEntityRef } from '@backstage/catalog-model';
import { InfoCard, Progress } from '@backstage/core-components';
import Alert$1 from '@material-ui/lab/Alert';
import CheckCircleOutlineIcon from '@material-ui/icons/CheckCircleOutline';
import RadioButtonUncheckedIcon from '@material-ui/icons/RadioButtonUnchecked';
import { o as opslevelApiRef } from './index-c532498e.esm.js';
import { useApi } from '@backstage/core-plugin-api';
import { useEntity } from '@backstage/plugin-catalog-react';
import { useAsyncFn, useAsync } from 'react-use';
import { Alert } from '@material-ui/lab';
import { Accordion, AccordionSummary, AccordionDetails, Typography as Typography$1, Tooltip as Tooltip$1 } from '@mui/material';
import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
import CheckCircleIcon from '@material-ui/icons/CheckCircle';
import CancelIcon from '@material-ui/icons/Cancel';
import WatchLaterIcon from '@material-ui/icons/WatchLater';
import ErrorIcon from '@material-ui/icons/Error';
import moment from 'moment';
import { Marked } from '@ts-stack/markdown';
import DOMPurify from 'dompurify';
import { truncate } from 'lodash';
import { withTheme, withStyles } from '@material-ui/core/styles';
import cloneDeep from 'lodash/cloneDeep';
import { a as levelColor } from './level_color_helper-6c12375f.esm.js';
import 'graphql-request';

const OverallLevel = ({ maturityReport }) => {
  return /* @__PURE__ */ React.createElement(InfoCard, {
    title: "Current Level"
  }, /* @__PURE__ */ React.createElement(Box, {
    sx: {
      borderColor: "primary.contrastText"
    },
    display: "inline-flex",
    justifyContent: "center",
    padding: "8px 20px",
    borderRadius: 3,
    border: 1,
    mb: 2,
    mt: 1
  }, /* @__PURE__ */ React.createElement(Typography, {
    variant: "h6"
  }, maturityReport.overallLevel.name)), /* @__PURE__ */ React.createElement("div", null, maturityReport.overallLevel.description));
};

const useStyles$2 = makeStyles((theme) => ({
  progressBar: {
    backgroundColor: theme.palette.success.main
  },
  achieved: {
    color: theme.palette.success.main
  },
  notAchieved: {
    color: "gray"
  }
}));
function determineProgress(level, serviceLevelIndex) {
  if (level.index < serviceLevelIndex)
    return 100;
  if (level.index === serviceLevelIndex)
    return 50;
  return 0;
}
function EntityOpsLevelMaturityProgress({ levels, serviceLevel }) {
  const classes = useStyles$2();
  const levelComponents = levels.map((level, index) => {
    const progress = determineProgress(level, serviceLevel.index);
    const last = index === levels.length - 1;
    const achieved = progress !== 0;
    const levelIcon = /* @__PURE__ */ React.createElement("div", {
      className: achieved ? classes.achieved : classes.notAchieved
    }, achieved ? /* @__PURE__ */ React.createElement(CheckCircleOutlineIcon, {
      color: "inherit"
    }) : /* @__PURE__ */ React.createElement(RadioButtonUncheckedIcon, {
      color: "inherit"
    }));
    const progressComponent = /* @__PURE__ */ React.createElement("div", {
      style: { width: "100%", marginTop: "20px" }
    }, /* @__PURE__ */ React.createElement(LinearProgress, {
      variant: "determinate",
      value: progress,
      classes: {
        bar1Determinate: classes.progressBar
      }
    }));
    return /* @__PURE__ */ React.createElement(React.Fragment, {
      key: index
    }, /* @__PURE__ */ React.createElement(Tooltip, {
      title: level.description,
      placement: "top",
      style: {
        flexGrow: 1,
        margin: "10px",
        display: "flex",
        flexDirection: "column",
        alignItems: "center"
      }
    }, /* @__PURE__ */ React.createElement("div", null, levelIcon, /* @__PURE__ */ React.createElement("div", {
      style: {
        width: "0px",
        height: "0px",
        display: "block",
        position: "relative",
        transform: "translate(-60px)"
      }
    }, /* @__PURE__ */ React.createElement("div", {
      style: {
        width: "120px",
        textAlign: "center",
        overflow: "hidden"
      }
    }, level.name)))), last ? null : progressComponent);
  });
  return /* @__PURE__ */ React.createElement(InfoCard, {
    title: "Progress"
  }, /* @__PURE__ */ React.createElement(Box, {
    style: {
      display: "inline-flex",
      alignItems: "start",
      justifyContent: "space-between",
      width: "100%",
      minHeight: "90px",
      paddingLeft: "25px",
      paddingRight: "25px"
    }
  }, levelComponents));
}

function SnackAlert(props) {
  return /* @__PURE__ */ React.createElement(Snackbar, {
    open: props.open,
    autoHideDuration: props.duration,
    onClose: () => {
      var _a;
      return (_a = props.setOpen) == null ? void 0 : _a.call(props, false);
    }
  }, /* @__PURE__ */ React.createElement(Alert, {
    severity: props.severity
  }, props.message));
}

const TRUNCATE_LENGTH = 100;
const NEWLINE_REGEX = /\r\n|\r|\n/;
class MarkdownViewer extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      sanitizedValue: !!props.value ? this.getDisplayValue(props.value, false) : "",
      sanitizedTruncatedValue: !!props.value ? this.getDisplayValue(props.value, true) : "",
      shouldTruncate: props.truncate && this.getCanTruncate(props.value),
      truncated: true
    };
  }
  componentDidUpdate(prevProps) {
    if (prevProps.value !== this.props.value || prevProps.truncate !== this.props.truncate) {
      this.setState({
        sanitizedValue: !!this.props.value ? this.getDisplayValue(this.props.value, false) : "",
        sanitizedTruncatedValue: !!this.props.value ? this.getDisplayValue(this.props.value, true) : "",
        shouldTruncate: this.props.truncate && this.getCanTruncate(this.props.value),
        truncated: this.state.truncated
      });
    }
  }
  getDisplayValue(value, doTruncate) {
    const text = doTruncate ? this.getTruncatedText(value) : value;
    return DOMPurify.sanitize(Marked.parse(text), { ADD_ATTR: ["target"] });
  }
  getToggleText() {
    return this.state.truncated ? "show more" : "show less";
  }
  getDisplayText() {
    return this.isTruncated() ? this.state.sanitizedTruncatedValue : this.state.sanitizedValue;
  }
  getCanTruncate(value) {
    if (!value)
      return false;
    return value.length > TRUNCATE_LENGTH || value.split(NEWLINE_REGEX).length > 2;
  }
  isTruncated() {
    return this.state.shouldTruncate && this.state.truncated;
  }
  getTruncatedText(value) {
    const result = value.split(NEWLINE_REGEX).slice(0, 2).join("\n").concat("\n");
    return `${truncate(result, {
      length: TRUNCATE_LENGTH,
      omission: " ...",
      separator: /,? + \r\n|\r|\n/
    })}`;
  }
  render() {
    const ret = [/* @__PURE__ */ React.createElement("span", {
      className: "span-markdown",
      key: "markup",
      dangerouslySetInnerHTML: { __html: this.getDisplayText() }
    })];
    if (this.state.shouldTruncate) {
      ret.push(/* @__PURE__ */ React.createElement("span", {
        className: "span-toggle-expansion",
        key: "markup-toggle-truncate",
        style: { color: this.props.theme.palette.link, textDecoration: "underline", cursor: "pointer" },
        onClick: () => this.setState({ ...this.state, truncated: !this.state.truncated })
      }, "(", this.getToggleText(), ")"));
    }
    return ret;
  }
}
var MarkdownViewer$1 = withTheme(MarkdownViewer);

const useStyles$1 = makeStyles((theme) => {
  return {
    coloredText: {
      color: `${theme.palette.text.primary} !important`
    },
    coloredSubtext: {
      color: `${theme.palette.text.secondary} !important`
    }
  };
});
const getShowWarnMessage = (checkResult) => {
  return ["payload", "generic"].includes(checkResult.check.type) && checkResult.warnMessage;
};
const getResultMessage = (checkResult) => {
  if (checkResult.check.type === "custom" && checkResult.status === "pending") {
    return "This is a Custom Check that has not been evaluated yet.  It requires an API request to be sent to our Custom Check API.";
  } else if (checkResult.status === "failed") {
    if (checkResult.check.type === "payload" || checkResult.check.type === "generic")
      return `**Error**:
${checkResult.message}`;
    return `<b>Error</b>: ${checkResult.message}`;
  }
  return checkResult.message;
};
function CheckResultDetails({ checkResult, combinedStatus }) {
  var _a;
  const styles = useStyles$1();
  const checkResultIcons = {
    "failed": /* @__PURE__ */ React.createElement(CancelIcon, null),
    "pending": /* @__PURE__ */ React.createElement(ErrorIcon, null),
    "passed": /* @__PURE__ */ React.createElement(CheckCircleIcon, null),
    "upcoming_failed": /* @__PURE__ */ React.createElement(WatchLaterIcon, null),
    "upcoming_pending": /* @__PURE__ */ React.createElement(WatchLaterIcon, null),
    "upcoming_passed": /* @__PURE__ */ React.createElement(WatchLaterIcon, null)
  };
  const resultColorMap = {
    "failed": {
      color: "#CF1322",
      backgroundColor: "#ff000033"
    },
    "pending": {
      color: "#FFC53D",
      backgroundColor: "#ffff0033"
    },
    "passed": {
      color: "#52C41A",
      backgroundColor: "#00ff0033"
    },
    "upcoming_failed": {
      color: "#CF1322",
      backgroundColor: "#00000033"
    },
    "upcoming_pending": {
      color: "#FFC53D",
      backgroundColor: "#00000033"
    },
    "upcoming_passed": {
      color: "#52C41A",
      backgroundColor: "#00000033"
    }
  };
  const CheckResultIcon = /* @__PURE__ */ React.createElement("div", {
    style: { color: resultColorMap[combinedStatus].color }
  }, checkResultIcons[combinedStatus]);
  return /* @__PURE__ */ React.createElement(Accordion, {
    id: `accordion-check-${checkResult.check.id}`,
    style: { ...resultColorMap[combinedStatus], color: "inherit" }
  }, /* @__PURE__ */ React.createElement(AccordionSummary, {
    expandIcon: /* @__PURE__ */ React.createElement(ExpandMoreIcon, null),
    style: {
      display: "inline-flex",
      width: "100%",
      overflow: "hidden"
    }
  }, CheckResultIcon, /* @__PURE__ */ React.createElement(Typography, {
    style: { marginLeft: "10px" },
    className: styles.coloredText
  }, checkResult.check.name, /* @__PURE__ */ React.createElement("span", {
    style: { fontSize: "smaller" },
    className: styles.coloredSubtext
  }, " \u2022 ", /* @__PURE__ */ React.createElement("b", null, ((_a = checkResult.check.category) == null ? void 0 : _a.name) || "Uncategorized"), " check"))), /* @__PURE__ */ React.createElement(AccordionDetails, {
    className: styles.coloredText,
    style: { marginTop: "-20px" }
  }, /* @__PURE__ */ React.createElement("p", {
    className: "p-will-be-enabled",
    hidden: !combinedStatus.startsWith("upcoming_")
  }, "This check will be enabled on ", moment.utc(checkResult.check.enableOn).format("MMMM Do YYYY, HH:mm:ss"), " (UTC)", /* @__PURE__ */ React.createElement("span", {
    className: "span-is-failing",
    hidden: combinedStatus !== "upcoming_failed"
  }, ", but it is currently failing."), /* @__PURE__ */ React.createElement("span", {
    className: "span-not-evaluated",
    hidden: combinedStatus !== "upcoming_pending"
  }, ", but it has not been evaluated yet."), /* @__PURE__ */ React.createElement("span", {
    className: "span-is-passing",
    hidden: combinedStatus !== "upcoming_passed"
  }, ", but it is currently passing.")), getShowWarnMessage(checkResult) && /* @__PURE__ */ React.createElement("span", {
    className: "span-warn-message"
  }, /* @__PURE__ */ React.createElement("p", {
    className: "p-unable-parse"
  }, "We were unable to fully parse the result message due to the following Liquid errors:"), /* @__PURE__ */ React.createElement(MarkdownViewer$1, {
    value: `<code>${checkResult.warnMessage}</code>`,
    truncate: true
  }), /* @__PURE__ */ React.createElement("p", {
    className: "p-unable-parse-following"
  }, "We were able to parse the following from the message:")), /* @__PURE__ */ React.createElement("div", {
    style: getShowWarnMessage(checkResult) ? { padding: "24px", backgroundColor: "rgba(0, 0, 0, 0.1)" } : {}
  }, /* @__PURE__ */ React.createElement("p", {
    className: "p-check-message"
  }, /* @__PURE__ */ React.createElement(MarkdownViewer$1, {
    value: getResultMessage(checkResult),
    truncate: false
  }))), getShowWarnMessage(checkResult) && /* @__PURE__ */ React.createElement("p", null, "Please fix and resend a payload to see an updated check result message."), /* @__PURE__ */ React.createElement("p", {
    className: `${styles.coloredSubtext} p-last-updated`,
    id: "trailer",
    hidden: !(checkResult.createdAt && checkResult.status !== "pending"),
    style: { fontSize: "smaller" }
  }, /* @__PURE__ */ React.createElement("b", null, "Last updated:"), " ", `${moment.utc(checkResult.createdAt).format("MMMM Do YYYY, HH:mm:ss")} (UTC)`)));
}

const useStyles = makeStyles((theme) => {
  return {
    accordion: {
      backgroundColor: `${theme.palette.background.default} !important`
    },
    accordionSummary: {
      backgroundColor: `${theme.palette.background.default} !important`,
      borderRadius: "5px !important",
      color: `${theme.palette.text.primary} !important`
    },
    accordionDetails: {
      backgroundColor: theme.palette.background.paper
    },
    coloredText: {
      color: `${theme.palette.text.primary} !important`
    },
    coloredSubtext: {
      color: `${theme.palette.text.secondary} !important`
    }
  };
});
function CheckResultsByLevel({ checkResultsByLevel, totalChecks, totalPassingChecks }) {
  const [checkResults, setCheckResults] = useState([]);
  const [levelCounts, setLevelCounts] = useState({});
  const [expandedLevels, setExpandedLevels] = useState({});
  const prevCheckResults = usePrevious(checkResults);
  const styles = useStyles();
  function usePrevious(value) {
    const ref = useRef();
    React.useEffect(() => {
      ref.current = value;
    });
    return ref.current;
  }
  React.useEffect(() => {
    function getLevelCounts(itemCheckResults) {
      const ret = {
        passed: 0,
        failed: 0,
        pending: 0,
        upcoming_passed: 0,
        upcoming_failed: 0,
        upcoming_pending: 0,
        upcoming: 0
      };
      for (const i in itemCheckResults) {
        if (!{}.hasOwnProperty.call(itemCheckResults, i))
          continue;
        const combinedStatus = getCombinedStatus(itemCheckResults[i]);
        if (combinedStatus in ret)
          ret[combinedStatus]++;
      }
      ret.upcoming = ret.upcoming_passed + ret.upcoming_failed + ret.upcoming_pending;
      return ret;
    }
    function getInitialExpandedLevelIndex(newLevelCounts) {
      for (const index in newLevelCounts) {
        if (newLevelCounts[index].failed > 0 || newLevelCounts[index].upcoming_failed > 0 || newLevelCounts[index].upcoming_pending > 0)
          return index;
      }
      return -1;
    }
    if (checkResultsByLevel !== prevCheckResults) {
      setCheckResults(checkResultsByLevel);
      const newLevelCounts = {};
      const newExpandedLevels = {};
      checkResultsByLevel.forEach(({ items, level }) => {
        newLevelCounts[level.index] = getLevelCounts(items.nodes);
      });
      const expandedLevelIndex = getInitialExpandedLevelIndex(newLevelCounts);
      for (const index in newLevelCounts) {
        if ({}.hasOwnProperty.call(newLevelCounts, index)) {
          newExpandedLevels[index] = expandedLevelIndex === index;
        }
      }
      setLevelCounts(newLevelCounts);
      setExpandedLevels(newExpandedLevels);
    }
  }, [checkResultsByLevel, prevCheckResults]);
  function getCombinedStatus(checkResult) {
    let status = checkResult.status;
    if (checkResult.check.enableOn !== null)
      status = `upcoming_${status}`;
    return status;
  }
  function getPassingPercentage() {
    return totalChecks === 0 ? 100 : Math.round(100 * totalPassingChecks / totalChecks);
  }
  const handleExpandedLevelIndexChange = (index) => (_event, newExpanded) => {
    const newExpandedLevels = cloneDeep(expandedLevels);
    newExpandedLevels[index] = !!newExpanded;
    setExpandedLevels(newExpandedLevels);
  };
  const accordionComponents = checkResults.map(({ items, level }) => {
    return /* @__PURE__ */ React.createElement(Accordion, {
      className: styles.accordion,
      key: level.name,
      expanded: expandedLevels[level.index],
      onChange: handleExpandedLevelIndexChange(level.index)
    }, /* @__PURE__ */ React.createElement(AccordionSummary, {
      className: styles.accordionSummary,
      key: `${level.name}-summary`,
      expandIcon: /* @__PURE__ */ React.createElement(ExpandMoreIcon, null)
    }, /* @__PURE__ */ React.createElement(Typography$1, {
      sx: { width: "90%" }
    }, level.name, " (", items.nodes.length, ")"), levelCounts[level.index].upcoming !== 0 && [
      /* @__PURE__ */ React.createElement(WatchLaterIcon, {
        key: `${level.name}-pending-icon`,
        style: { color: "#8C8C8C" }
      }),
      /* @__PURE__ */ React.createElement("p", {
        key: `${level.name}-pending-p`,
        style: { lineHeight: "24px", margin: "0px 15px 0px 5px" }
      }, levelCounts[level.index].upcoming)
    ], levelCounts[level.index].pending !== 0 && [
      /* @__PURE__ */ React.createElement(ErrorIcon, {
        key: `${level.name}-warning-icon`,
        style: { color: "#FFC53D" }
      }),
      /* @__PURE__ */ React.createElement("p", {
        key: `${level.name}-warning-p`,
        style: { lineHeight: "24px", margin: "0px 15px 0px 5px" }
      }, levelCounts[level.index].pending)
    ], /* @__PURE__ */ React.createElement(CancelIcon, {
      style: { color: "#CF1322" }
    }), /* @__PURE__ */ React.createElement("p", {
      style: { lineHeight: "24px", margin: "0px 15px 0px 5px" }
    }, levelCounts[level.index].failed), /* @__PURE__ */ React.createElement(CheckCircleIcon, {
      style: { color: "#52C41A" }
    }), /* @__PURE__ */ React.createElement("p", {
      style: { lineHeight: "24px", margin: "0px 15px 0px 5px" }
    }, levelCounts[level.index].passed)), /* @__PURE__ */ React.createElement(AccordionDetails, {
      className: styles.accordionDetails
    }, items.nodes.map((checkResult, index) => {
      return /* @__PURE__ */ React.createElement(CheckResultDetails, {
        key: `details-${level.name}-${index}`,
        checkResult,
        combinedStatus: getCombinedStatus(checkResult)
      });
    }), items.nodes.length === 0 && /* @__PURE__ */ React.createElement("p", {
      className: styles.coloredText
    }, "There are no checks in this level.")));
  });
  return /* @__PURE__ */ React.createElement(InfoCard, {
    title: "Checks",
    subheader: `Total Checks Passing: ${totalPassingChecks} / ${totalChecks} (${getPassingPercentage()}%)`
  }, accordionComponents);
}

const styles = (theme) => {
  return {
    levelHeaderRow: {
      textAlign: "center"
    },
    levelHeaderCell: {
      padding: "5px",
      paddingBottom: "10px",
      overflow: "hidden",
      textOverflow: "ellipsis",
      whiteSpace: "nowrap",
      color: theme.palette.text.primary
    },
    categoryHeaderCell: {
      textAlign: "right",
      color: theme.palette.text.primary,
      overflow: "hidden",
      textOverflow: "ellipsis",
      whiteSpace: "nowrap"
    },
    inactiveCategoryHeaderCell: {
      textAlign: "right",
      color: theme.palette.text.disabled,
      overflow: "hidden",
      textOverflow: "ellipsis",
      whiteSpace: "nowrap"
    },
    fieldCell: {
      textAlign: "center"
    },
    field: {
      display: "inline-block",
      width: "calc(100% - 10px)",
      height: "20px",
      marginLeft: "5px",
      marginRight: "5px",
      borderRadius: "2px",
      maxWidth: "70px"
    },
    inactiveField: {
      border: `1px solid ${theme.palette.border}`,
      backgroundColor: theme.palette.background.default
    },
    disabledField: {
      border: `1px solid ${theme.palette.border}`,
      backgroundColor: theme.palette.background.paper
    }
  };
};
class Scorecard extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      sortedLevels: [...props.levels].sort(
        (a, b) => a.index - b.index
      )
    };
  }
  getFieldStyle(classes, activeLevel, currentLevel) {
    if (activeLevel === null)
      return [`${classes.field} ${classes.disabledField}`, {}];
    if (activeLevel.name !== currentLevel.name)
      return [`${classes.field} ${classes.inactiveField}`, {}];
    const color = levelColor(
      this.state.sortedLevels.length,
      this.state.sortedLevels.indexOf(currentLevel)
    );
    return [classes.field, {
      backgroundColor: color.secondary,
      border: `solid 1px ${color.secondary}`
    }];
  }
  getFieldCell(classes, categoryLevel, renderingLevel) {
    return /* @__PURE__ */ React.createElement("div", {
      className: this.getFieldStyle(classes, categoryLevel, renderingLevel)[0],
      style: this.getFieldStyle(classes, categoryLevel, renderingLevel)[1]
    });
  }
  getWrappedFieldCell(classes, levelCategory, renderingLevel) {
    const content = this.getFieldCell(classes, levelCategory.level, renderingLevel);
    if (levelCategory.level === null || levelCategory.level.name !== renderingLevel.name) {
      return content;
    }
    return /* @__PURE__ */ React.createElement(Tooltip$1, {
      key: `tt_cat_${levelCategory.category.name}_lvl_${renderingLevel.name}}`,
      title: /* @__PURE__ */ React.createElement("span", {
        style: { fontSize: "14px" }
      }, levelCategory.level.name),
      "aria-label": levelCategory.level.name,
      placement: "top"
    }, content);
  }
  render() {
    const { classes } = this.props;
    return /* @__PURE__ */ React.createElement(InfoCard, {
      title: "Scorecard"
    }, /* @__PURE__ */ React.createElement("table", {
      style: {
        width: "100%",
        tableLayout: "fixed"
      }
    }, /* @__PURE__ */ React.createElement("tbody", null, !!this.props.levelCategories && this.props.levelCategories.map((lc) => /* @__PURE__ */ React.createElement("tr", {
      key: `cat_${lc.category.name}`
    }, /* @__PURE__ */ React.createElement("td", {
      className: !!lc.level ? classes.categoryHeaderCell : classes.inactiveCategoryHeaderCell
    }, /* @__PURE__ */ React.createElement(Tooltip$1, {
      title: lc.category.name,
      placement: "top"
    }, /* @__PURE__ */ React.createElement("span", null, lc.category.name))), this.state.sortedLevels.map((level) => /* @__PURE__ */ React.createElement("td", {
      key: `cat_${lc.category.name}_lvl_${level.name}`,
      className: classes.fieldCell,
      style: {
        width: `${75 / this.state.sortedLevels.length}%`
      }
    }, this.getWrappedFieldCell(classes, lc, level))))))));
  }
}
var Scorecard$1 = withStyles(styles)(Scorecard);

const EntityOpsLevelMaturityContent = () => {
  var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k, _l, _m, _n, _o, _p;
  const { entity } = useEntity();
  const opslevelApi = useApi(opslevelApiRef);
  const serviceAlias = stringifyEntityRef(entity);
  const [opsLevelData, setOpsLevelData] = useState();
  const [exporting, setExporting] = useState(false);
  const [snackbarOpen, setSnackbarOpen] = useState(false);
  const [snackbar, setSnackbar] = useState({ message: "", severity: "info" });
  const [fetchState, doFetch] = useAsyncFn(async () => {
    const result = await opslevelApi.getServiceMaturityByAlias(serviceAlias);
    if (result) {
      setOpsLevelData(result);
    }
  });
  useAsync(doFetch, [serviceAlias]);
  if (fetchState.loading || exporting) {
    return /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(SnackAlert, {
      ...snackbar,
      open: snackbarOpen,
      setOpen: setSnackbarOpen
    }), /* @__PURE__ */ React.createElement(Progress, null));
  }
  if (fetchState.error) {
    return /* @__PURE__ */ React.createElement(Alert$1, {
      severity: "error"
    }, (_a = fetchState.error) == null ? void 0 : _a.message);
  }
  const service = (_b = opsLevelData == null ? void 0 : opsLevelData.account) == null ? void 0 : _b.service;
  if (!service) {
    const error = /* @__PURE__ */ React.createElement("span", null, "OpsLevel doesn't know about this service. Export it to get started.", /* @__PURE__ */ React.createElement("br", null), "Alternatively, you can export all entities at once from\xA0", /* @__PURE__ */ React.createElement("a", {
      href: "/opslevel-maturity",
      target: "_blank",
      style: { textDecoration: "underline" }
    }, "the Maturity page"), ".");
    return /* @__PURE__ */ React.createElement(ServiceMaturityError, {
      error,
      showExport: true
    });
  }
  const { maturityReport } = service;
  const levels = (_e = (_d = (_c = opsLevelData.account) == null ? void 0 : _c.rubric) == null ? void 0 : _d.levels) == null ? void 0 : _e.nodes;
  const levelCategories = (_h = (_g = (_f = opsLevelData.account) == null ? void 0 : _f.service) == null ? void 0 : _g.maturityReport) == null ? void 0 : _h.categoryBreakdown;
  const checkResultsByLevel = (_n = (_m = (_l = (_k = (_j = (_i = opsLevelData.account) == null ? void 0 : _i.service) == null ? void 0 : _j.serviceStats) == null ? void 0 : _k.rubric) == null ? void 0 : _l.checkResults) == null ? void 0 : _m.byLevel) == null ? void 0 : _n.nodes;
  const checkStats = (_p = (_o = opsLevelData.account) == null ? void 0 : _o.service) == null ? void 0 : _p.checkStats;
  if (!maturityReport) {
    return /* @__PURE__ */ React.createElement(ServiceMaturityError, {
      error: "We don't have any maturity details for this service yet, please check back in a few minutes."
    });
  }
  async function exportEntity(event) {
    event.preventDefault();
    setExporting(true);
    showSnackbar({ message: "Updating service in OpsLevel...", severity: "info" });
    const result = await opslevelApi.exportEntity(entity);
    showSnackbar({ message: result == null ? void 0 : result.importEntityFromBackstage.actionMessage, severity: "success", duration: 5e3 });
    setExporting(false);
    doFetch();
  }
  function showSnackbar(snackbarProps) {
    setSnackbarOpen(true);
    setSnackbar({ ...snackbarProps });
  }
  function ServiceMaturityError({ error, showExport }) {
    return /* @__PURE__ */ React.createElement(Grid, {
      container: true,
      spacing: 5
    }, /* @__PURE__ */ React.createElement(SnackAlert, {
      ...snackbar,
      open: snackbarOpen,
      setOpen: setSnackbarOpen
    }), /* @__PURE__ */ React.createElement(Grid, {
      item: true
    }, error), /* @__PURE__ */ React.createElement(Grid, {
      item: true
    }, showExport ? /* @__PURE__ */ React.createElement(Button, {
      variant: "contained",
      color: "primary",
      onClick: exportEntity,
      disabled: exporting
    }, "Export Entity to OpsLevel") : /* @__PURE__ */ React.createElement(Button, {
      variant: "contained",
      color: "primary",
      target: "_blank",
      href: `${service == null ? void 0 : service.htmlUrl}/maturity-report`
    }, "View Maturity in OpsLevel")));
  }
  function ServiceMaturityReport() {
    return /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(Grid, {
      container: true,
      item: true,
      xs: 12,
      justifyContent: "flex-end"
    }, /* @__PURE__ */ React.createElement(Grid, {
      item: true
    }, /* @__PURE__ */ React.createElement(Button, {
      variant: "contained",
      color: "primary",
      onClick: exportEntity,
      disabled: exporting
    }, "Update Entity")), /* @__PURE__ */ React.createElement(Grid, {
      item: true
    }, /* @__PURE__ */ React.createElement(Button, {
      variant: "contained",
      color: "primary",
      target: "_blank",
      href: `${service == null ? void 0 : service.htmlUrl}/maturity-report`
    }, "View Maturity in OpsLevel"))), /* @__PURE__ */ React.createElement(Grid, {
      container: true,
      item: true
    }, /* @__PURE__ */ React.createElement(Grid, {
      container: true,
      item: true,
      xs: 4,
      direction: "column"
    }, /* @__PURE__ */ React.createElement(Grid, {
      item: true
    }, /* @__PURE__ */ React.createElement(OverallLevel, {
      maturityReport
    })), /* @__PURE__ */ React.createElement(Grid, {
      item: true
    }, /* @__PURE__ */ React.createElement(Scorecard$1, {
      levels,
      levelCategories
    }))), /* @__PURE__ */ React.createElement(Grid, {
      container: true,
      item: true,
      xs: 8,
      direction: "column"
    }, /* @__PURE__ */ React.createElement(Grid, {
      item: true
    }, /* @__PURE__ */ React.createElement(EntityOpsLevelMaturityProgress, {
      levels,
      serviceLevel: maturityReport == null ? void 0 : maturityReport.overallLevel
    })), /* @__PURE__ */ React.createElement(Grid, {
      item: true
    }, /* @__PURE__ */ React.createElement(CheckResultsByLevel, {
      checkResultsByLevel,
      totalChecks: checkStats.totalChecks,
      totalPassingChecks: checkStats.totalPassingChecks
    })))));
  }
  return /* @__PURE__ */ React.createElement(Grid, {
    container: true,
    spacing: 2
  }, /* @__PURE__ */ React.createElement(SnackAlert, {
    ...snackbar,
    open: snackbarOpen,
    setOpen: setSnackbarOpen
  }), /* @__PURE__ */ React.createElement(ServiceMaturityReport, null));
};

export { EntityOpsLevelMaturityContent };
//# sourceMappingURL=EntityOpsLevelMaturityContent-7b82034f.esm.js.map
